/* Define this if SYSV IPC is available (e.g. msgget, etc.) */
#undef HAVE_SYSVIPC

/* Define this if internet-domain sockets are available */
#undef HAVE_INTERNET_DOMAIN_SOCKETS

/* Define this if berkeley unix-domain sockets are available */
#undef HAVE_UNIX_DOMAIN_SOCKETS

/* Define this if have sun_len member in struct sockaddr_un */
#undef HAVE_SOCKADDR_SUN_LEN

/* Define this if using Xauth authentication */
#undef HAVE_XAUTH

#undef socklen_t

#undef HAVE_X_WINDOWS

#undef _GNU_SOURCE
